from cmtt.data import *

# Load online resource files
print("Load url function")
result_json = load_url('https://world.openfoodfacts.org/api/v0/product/5060292302201.json')
print(result_json['code'])

result_csv = load_url('https://gist.githubusercontent.com/rnirmal/e01acfdaf54a6f9b24e91ba4cae63518/raw/6b589a5c5a851711e20c5eb28f9d54742d1fe2dc/datasets.csv')
print(result_csv['about'][20])
print(len(result_csv['about']))
print()

# List CMTT dataset keys and all available cmtt datasets
print("List dataset keys and cmtt datasets function")
keys = list_dataset_keys()
print(keys)

data = list_cmtt_datasets()
print(data)
print()

# Download cmtt datasets
print("Download cmtt datasets function")
lst = download_cmtt_datasets(["linc_ner_hineng", "L3Cube_HingLID_all", "linc_lid_spaeng"])

print()
path = download_dataset_url('https://world.openfoodfacts.org/api/v0/product/5060292302201.json')

print()
print(lst)
print(path)


import unittest
from cmtt.data import *

class CMTTTestCase(unittest.TestCase):
  def setUp(self):
    self.load_url = load_url
    self.list_dataset_keys = list_dataset_keys

  def test_data_load_url_1(self):
    """Test data load_url function 1"""
    result = self.load_url('https://world.openfoodfacts.org/api/v0/product/5060292302201.json')
    self.assertEqual(result['code'], "5060292302201")

  def test_data_load_url_2(self):
    """Test data load_url function 2"""
    result = self.load_url('https://gist.githubusercontent.com/rnirmal/e01acfdaf54a6f9b24e91ba4cae63518/raw/6b589a5c5a851711e20c5eb28f9d54742d1fe2dc/datasets.csv')
    self.assertEqual(result['about'][20], "Tate Collection metadata")
    self.assertEqual(len(result['about']), 61)

  def test_list_dataset_keys(self):
    """Test list_dataset_keys function"""
    keys = self.list_dataset_keys()
    self.assertEqual(keys, ['url', 'id', 'name', 'format', 'language', 'task', 'credits', 'source', 'last_modified'])
  
if __name__ == '__main__':
  unittest.main()


# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
  long_description = f.read()

# This call to setup() does all the work
setup(
  name="cmtt",
  version="0.1.0",
  description="A library for processing Code Mixed Text. Still in development!",
  long_description_content_type="text/markdown",
  long_description=long_description,
  url="https://cmtt.readthedocs.io/",
  author="Reuben Devanesan",
  author_email="reubendevanesan@gmail.com",
  license="MIT",
  classifiers=[
      "Intended Audience :: Developers",
      "License :: OSI Approved :: MIT License",
      "Programming Language :: Python",
      "Programming Language :: Python :: 3",
      "Programming Language :: Python :: 3.9",
      "Programming Language :: Python :: 3.10",
      "Operating System :: OS Independent"
  ],
  # packages=["cmtt", "cmtt/data", "cmtt/preprocessing"],
  packages=find_packages(),
  include_package_data=True,
  data_files=[('cmtt/data', ['cmtt/data/data.json'])],
  install_requires=["numpy", "pandas", "requests", "tqdm"]
)